You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@apr.apache.org by yl...@apache.org on 2014/07/16 19:59:51 UTC

svn commit: r1611117 - /apr/apr/trunk/tables/apr_skiplist.c

Author: ylavic
Date: Wed Jul 16 17:59:50 2014
New Revision: 1611117

URL: http://svn.apache.org/r1611117
Log:
Use apr_skiplist_add() instead of apr_skiplist_insert() to merge skiplists
since doublons need to be merged too.

Modified:
    apr/apr/trunk/tables/apr_skiplist.c

Modified: apr/apr/trunk/tables/apr_skiplist.c
URL: http://svn.apache.org/viewvc/apr/apr/trunk/tables/apr_skiplist.c?rev=1611117&r1=1611116&r2=1611117&view=diff
==============================================================================
--- apr/apr/trunk/tables/apr_skiplist.c (original)
+++ apr/apr/trunk/tables/apr_skiplist.c Wed Jul 16 17:59:50 2014
@@ -648,10 +648,10 @@ APR_DECLARE(apr_skiplist *) apr_skiplist
         apr_skiplist_remove_all(sl2, NULL);
         return sl1;
     }
     /* This is what makes it brute force... Just insert :/ */
     b2 = apr_skiplist_getlist(sl2);
     while (b2) {
-        apr_skiplist_insert(sl1, b2->data);
+        apr_skiplist_add(sl1, b2->data);
         apr_skiplist_next(sl2, &b2);
     }
     apr_skiplist_remove_all(sl2, NULL);
@@ -648,10 +648,10 @@ APR_DECLARE(apr_skiplist *) apr_skiplist
         return sl1;
     }
-    /* This is what makes it brute force... Just insert :/ */
+    /* This is what makes it brute force... Just add :/ */
     b2 = apr_skiplist_getlist(sl2);
     while (b2) {